import uk.ac.ed.ph.jfftw.*;

/**        Test program for cube (three-D real) FFTW
 *         Note MUST be run with
 *         java -Xmx256m CubeTest
 *         (-Xmx256m increases the max memory stack to 256meg)
 *         (works only on Unix where non-standard -X option is implememted)
 */
public class CubeTest {
    public static void main(String args[]) {

	int width = 256;
	int height = 256;
	int depth = 256;

	//           Make a double array of currect size

	double d[]= new double[width*height*depth];

	System.out.println("Length of initial array is " + d.length);

	//          Set elements to random number between 0-10

	for(int i = 0; i < d.length; i++) {
	    d[i] = 10.0*Math.random();
	}

	//          Make the real fftw
	FFTWReal fftw = new FFTWReal();

	//          Take out of place FFT to complex
	double ft[] = fftw.threeDimensionalForward(width,height,depth,d);

	System.out.println("Length of ft is " + ft.length);

	//          Reconstruct
	double recon[] = fftw.threeDimensionalBackward(width,height,depth,ft);
	
	System.out.println("Length of reconstruction is " + recon.length);


	//          Scale the inverse by 1/N to (no scale in FFTW)
	double scale = 1.0/(width*height*depth);
	for(int i = 0; i < recon.length; i++) {
	    recon[i] *= scale;
	}


	//          Calcualte diff square between d and recon
	double diff = 0.0;
	for(int i = 0; i < recon.length; i++) {
	    double e = d[i] - recon[i];
	    diff += Math.abs(e);
	}

	//          Print out the result
	System.out.println("Difference is " + diff);



    }
}
